@@ -1,17 +1,19 @@
 context('show_package_stats')
 
-filename <- '/test_source_show_package_stats.R'
+filename <- 'test_source_show_package_stats.R'
 test_dir <- 'show_package_stats'
 temp_dir <- tempdir()
-testpath <- paste0(temp_dir, test_dir)
-filepath <- paste0(testpath, filename)
-dir.create(paste0(temp_dir, test_dir))
+testpath <- file.path(temp_dir, test_dir)
+filepath <- file.path(testpath, filename)
+dir.create(testpath)
 
 con <- file(filepath)
 test_source <- 'library("dplyr")
 # library(notused)
-ggplot2::filter()
-require(reshape2)'
+ggplot2::filter(),
+scales:::comma(),
+require(reshape2),
+suppressPackageStartupMessages(library(shiny))'
 writeLines(text = test_source, con = con)
 result <- show_package_stats(path = testpath)
 close(con)
@@ -24,5 +26,5 @@ test_that('show_package_stats finds only used packages', {
 })
 
 test_that('show_package_stats finds the correct number of packages',
-  expect_equal(length(result[result$package %in% c('dplyr', 'ggplot2', 'reshape2'), 'n']), 3)
+  expect_equal(length(result[result$package %in% c('dplyr', 'ggplot2', 'reshape2', 'shiny', 'scales'), 'n']), 5)
 )
